@@ -2,7 +2,7 @@ package Test2::Hub;
 use strict;
 use warnings;
 
-our $VERSION = '1.302124'; # TRIAL
+our $VERSION = '1.302126'; # TRIAL
 
 
 use Carp qw/carp croak confess/;
@@ -25,6 +25,7 @@ use Test2::Util::HashBase qw{
     _context_init
     _context_release
 
+    uuid
     active
     count
     failed
@@ -35,14 +36,20 @@ use Test2::Util::HashBase qw{
     skip_reason
 };
 
+my $UUID_VIA;
+
 my $ID_POSTFIX = 1;
 sub init {
     my $self = shift;
 
+
     $self->{+PID} = $$;
     $self->{+TID} = get_tid();
     $self->{+HID} = join ipc_separator, $self->{+PID}, $self->{+TID}, $ID_POSTFIX++;
 
+    $UUID_VIA ||= Test2::API::_add_uuid_via_ref();
+    $self->{+UUID} = ${$UUID_VIA}->('hub') if $$UUID_VIA;
+
     $self->{+NESTED}   = 0 unless defined $self->{+NESTED};
     $self->{+BUFFERED} = 0 unless defined $self->{+BUFFERED};
 
@@ -303,6 +310,8 @@ sub process {
         }
     }
 
+    $e->set_uuid(${$UUID_VIA}->('event')) if $$UUID_VIA;
+
     # Optimize the most common case
     my $type = ref($e);
     if ($type eq 'Test2::Event::Pass' || ($type eq 'Test2::Event::Ok' && $e->{pass})) {
@@ -775,6 +784,10 @@ Get the thread id under which the hub was created.
 
 Get the identifier string of the hub.
 
+=item $uuid = $hub->uuid()
+
+If UUID tagging is enabled (see L<Test2::API>) then the hub will have a UUID.
+
 =item $ipc = $hub->ipc()
 
 Get the IPC object used by the hub.
